import { app, BrowserWindow, ipcMain } from 'electron';
import * as path from 'path';
import * as url from 'url';
import * as fs from 'fs';
import * as grpc from 'grpc';

import * as CDPServiceProto from '@odds-crawler/proto/cdp/cdp.service_pb';
import * as CDPServiceGRpcProto from '@odds-crawler/proto/cdp/cdp.service_grpc_pb';

process.env['ELECTRON_DISABLE_SECURITY_WARNINGS'] = 'true';

const appDir = path.join(__dirname, `../../dist/odds-crawler-frontend-app`);

let mainWindow: BrowserWindow;

app.on('ready', createWindow);

app.on('activate', () => {
  if (null === mainWindow) {
    createWindow();
  }
});

app.on('window-all-closed', () => {
  // On OS X it is common for applications and their menu bar
  // to stay active until the user quits explicitly with Cmd + Q
  if ('darwin' !== process.platform) {
    app.quit();
  }
});

function createWindow() {
  mainWindow = new BrowserWindow({
    width: 800,
    height: 600,
    webPreferences: { nodeIntegration: true }
  });

  mainWindow.loadURL(
    url.format({
      pathname: path.join(appDir, `/index.html`),
      protocol: 'file:',
      slashes: true
    })
  );

  mainWindow.webContents.openDevTools();

  mainWindow.on('closed', () => {
    mainWindow = null;
  });

  let cdpServiceClient = new CDPServiceGRpcProto.CDPServiceClient(
    'localhost:50051',
    grpc.credentials.createInsecure()
  );

  // let req: CDPServiceProto.NavigateRequest;
  // let res: CDPServiceProto.NavigateReply;

  // req = new CDPServiceProto.NavigateRequest();
  // req.setUrl('https://www.google.com');

  // cdpServiceClient.navigate(req, (err, res) => {
  //   if (err) {
  //     console.log(err);
  //     return;
  //   }
  //   console.log(res);
  // });
}

ipcMain.on('getFiles', (event, arg) => {
  const files = fs.readdirSync(__dirname);
  mainWindow.webContents.send('getFilesResponse', files);
});
